Learn R Programming

Characterization (version 3.0.0)

cleanIncremental: Removes csv files from folders that have not been marked as completed and removes the record of the execution file

Description

Removes csv files from folders that have not been marked as completed and removes the record of the execution file

Usage

cleanIncremental(executionFolder, ignoreWhenEmpty = FALSE)

Value

A list with the settings

Arguments

executionFolder

The folder that has the execution files

ignoreWhenEmpty

When TRUE, if there are no incremental logs then nothing is run

See Also

Other Incremental: cleanNonIncremental()

Examples

Run this code

cleanIncremental(
  file.path(tempdir(), 'incremental'),
  ignoreWhenEmpty = TRUE
)


Run the code above in your browser using DataLab