Learn R Programming

Characterization (version 3.0.0)

cleanNonIncremental: Removes csv files from the execution folder as there should be no csv files when running in non-incremental model

Description

Removes csv files from the execution folder as there should be no csv files when running in non-incremental model

Usage

cleanNonIncremental(executionFolder)

Value

A list with the settings

Arguments

executionFolder

The folder that has the execution files

See Also

Other Incremental: cleanIncremental()

Examples

Run this code
# example code

cleanNonIncremental(file.path(tempdir(), 'incremental'))

Run the code above in your browser using DataLab