powered by
This function creates a connection to an sqlite database
createSqliteDatabase(sqliteLocation = tempdir())
Returns the connection detail object to the sqlite database
The location of the sqlite database
This function creates a sqlite database and connection
Other Database: createCharacterizationTables(), insertResultsToDatabase()
createCharacterizationTables()
insertResultsToDatabase()
charResultDbCD <- createSqliteDatabase()
Run the code above in your browser using DataLab