powered by
Removes csv files from folders that have not been marked as completed and removes the record of the execution file
cleanIncremental(executionFolder, ignoreWhenEmpty = FALSE)
A list with the settings
The folder that has the execution files
When TRUE, if there are no incremental logs then nothing is run
Other Incremental: cleanNonIncremental()
cleanNonIncremental()
cleanIncremental( file.path(tempdir(), 'incremental'), ignoreWhenEmpty = TRUE )
Run the code above in your browser using DataLab