powered by
Removes csv files from the execution folder as there should be no csv files when running in non-incremental model
cleanNonIncremental(executionFolder)
A list with the settings
The folder that has the execution files
Other Incremental: cleanIncremental()
cleanIncremental()
# example code cleanNonIncremental(file.path(tempdir(), 'incremental'))
Run the code above in your browser using DataLab