powered by
This function executes a large set of SQL statements to create tables that can store results
createCharacterizationTables( connectionDetails, resultSchema, targetDialect = "postgresql", deleteExistingTables = TRUE, createTables = TRUE, tablePrefix = "c_", tempEmulationSchema = getOption("sqlRenderTempEmulationSchema") )
Returns NULL but creates the required tables into the specified database schema.
The connectionDetails to a database created by using the function createConnectDetails in the DatabaseConnector package.
createConnectDetails
DatabaseConnector
The name of the database schema that the result tables will be created.
The database management system being used
If true any existing tables matching the Characterization result tables names will be deleted
If true the Characterization result tables will be created
A string appended to the Characterization result tables
The temp schema used when the database management system is oracle
This function can be used to create (or delete) Characterization result tables
Other Database: createSqliteDatabase(), insertResultsToDatabase()
createSqliteDatabase()
insertResultsToDatabase()
# create sqlite database charResultDbCD <- createSqliteDatabase() # create database results tables createCharacterizationTables( connectionDetails = charResultDbCD, resultSchema = 'main' )
Run the code above in your browser using DataLab