Create dechallenge rechallenge study settings
Source:R/DechallengeRechallenge.R
createDechallengeRechallengeSettings.RdCreate dechallenge rechallenge study settings
Usage
createDechallengeRechallengeSettings(
studyPopulationSettings,
outcomeIds,
dechallengeStopInterval = 30,
dechallengeEvaluationWindow = 30
)Arguments
- studyPopulationSettings
An object created using
createStudyPopulationSettingsof a list ofcreateStudyPopulationSettingsthat specifies cohort inclusion criteria- outcomeIds
A list of cohortIds for the outcome cohorts
- dechallengeStopInterval
An integer specifying the how much time to add to the cohort_end when determining whether the event starts during cohort and ends after
- dechallengeEvaluationWindow
An integer specifying the period of time after the cohort_end when you cannot see an outcome for a dechallenge success
Examples
drSet <- createDechallengeRechallengeSettings(
studyPopulationSettings = createStudyPopulationSettings(
targetIds = c(1,2),
limitToFirstInNDays = 0,
minPriorObservation = 0
),
outcomeIds = 3
)