powered by
Create dechallenge rechallenge study settings
createDechallengeRechallengeSettings( targetIds, outcomeIds, dechallengeStopInterval = 30, dechallengeEvaluationWindow = 30 )
A list with the settings
A list of cohortIds for the target cohorts
A list of cohortIds for the outcome cohorts
An integer specifying the how much time to add to the cohort_end when determining whether the event starts during cohort and ends after
An integer specifying the period of time after the cohort_end when you cannot see an outcome for a dechallenge success
Other DechallengeRechallenge: computeDechallengeRechallengeAnalyses(), computeRechallengeFailCaseSeriesAnalyses()
computeDechallengeRechallengeAnalyses()
computeRechallengeFailCaseSeriesAnalyses()
drSet <- createDechallengeRechallengeSettings( targetIds = c(1,2), outcomeIds = 3 )
Run the code above in your browser using DataLab