exampleOmopConnectionDetails: create a connection detail for an example GI Bleed dataset from Eunomia
Description
This returns an object of class `ConnectionDetails` that lets you connect via `DatabaseConnector::connect()` to the example database.
Usage
exampleOmopConnectionDetails(exdir = tempdir())
Value
An object of class `ConnectionDetails` with the details to connect to the example OHDSI OMOP CDM database
Arguments
exdir
a directory to unzip the example OMOP database into. Default is tempdir().
Details
Finds the location of the example database in the package and calls `DatabaseConnector::createConnectionDetails` to create a `ConnectionDetails` object for connecting to the database.