Learn R Programming

Characterization (version 3.0.0)

loadCharacterizationSettings: Load the characterization settings previously saved as a json file

Description

This function converts the json file back into an R object

Usage

loadCharacterizationSettings(fileName)

Value

Returns the json settings as an R object

Arguments

fileName

The location of the the json settings

Details

Input the directory containing the 'characterizationSettings.json' file and load the settings into R

See Also

Other LargeScale: createCharacterizationSettings(), runCharacterizationAnalyses(), saveCharacterizationSettings()

Examples

Run this code
# example code

setPath <- file.path(tempdir(), 'charSet.json')

drSet <- createDechallengeRechallengeSettings(
  targetIds = c(1,2),
  outcomeIds = 3
)

cSet <- createCharacterizationSettings(
  dechallengeRechallengeSettings = drSet
)

saveCharacterizationSettings(
  settings = cSet,
  fileName = setPath
)

setting <- loadCharacterizationSettings(setPath)


Run the code above in your browser using DataLab