- connectionDetails
The connection details to the database containing the OMOP CDM data
- targetDatabaseSchema
Schema name where your target cohort table resides. Note that for SQL Server,
this should include both the database and schema name, for example
'scratch.dbo'.
- targetTable
Name of the target cohort table.
- outcomeDatabaseSchema
Schema name where your outcome cohort table resides. Note that for SQL Server,
this should include both the database and schema name, for example
'scratch.dbo'.
- outcomeTable
Name of the outcome cohort table.
- outputDatabaseSchema
The schema where the characterization cohort table will be saved into
- outputTable
The table name where the characterization cohort table will be saved into
- tempEmulationSchema
Some database platforms like Oracle and Impala do not truly support temp tables.
To emulate temp tables, provide a schema with write privileges where temp tables
can be created
- cdmDatabaseSchema
The schema with the OMOP CDM data
- characterizationSettings
The study settings created using createCharacterizationSettings
- outputDirectory
The location to save the final csv files to
- executionPath
The location where intermediate results are saved to
- csvFilePrefix
A string to append the csv files in the outputDirectory
- databaseId
The unique identifier for the cdm database
- showSubjectId
Whether to include subjectId of failed rechallenge case series or hide
- minCellCount
The minimum count value that is calculated
- incremental
If TRUE then skip previously executed analyses that completed
- threads
The number of threads to use when running analyses jobs in parallel
- cohortGenerationThreads
(optional) The number of threads to use when generating the cohorts in parallel (Note: some database management systems do not allow insert parallelization)
- nTargetJobs
Partition the targets into this number of groups (e.g., if there are 20 targets and njobs is 5 then there will be 4 targets per job and 5 jobs)
- minCharacterizationMean
The minimum mean threshold to extract when running aggregate covariates
- minCovariateCount
The minimum number of patients who must have the covariate when running aggregate covariates
- mode
Select from Efficient (no exclusions to target based on washout)/CohortIncidence (excludes targets with outcome in washout if they have no time at risk)/PatientLevelPrediction (excludes targets with outcome during washout prior to index)
- minSMD
The minimum standardized mean difference for the risk factor analysis