Learn R Programming

Characterization (version 3.0.0)

viewCharacterization: viewCharacterization - Interactively view the characterization results

Description

This is a shiny app for viewing interactive plots and tables

Usage

viewCharacterization(resultFolder, cohortDefinitionSet = NULL)

Value

Opens a shiny app for interactively viewing the results

Arguments

resultFolder

The location of the csv results

cohortDefinitionSet

The cohortDefinitionSet extracted using webAPI

Details

Input is the output of ...

Examples

Run this code

conDet <- exampleOmopConnectionDetails()

tteSet <- createTimeToEventSettings(
  targetIds = c(1,2),
  outcomeIds = 3
)

cSet <- createCharacterizationSettings(
  timeToEventSettings = tteSet
)

runCharacterizationAnalyses(
  connectionDetails = conDet,
  targetDatabaseSchema = 'main',
  targetTable = 'cohort',
  outcomeDatabaseSchema = 'main',
  outcomeTable = 'cohort',
  cdmDatabaseSchema = 'main',
  characterizationSettings = cSet,
  outputDirectory = file.path(tempdir(),'view')
)

# interactive shiny app
if (FALSE) {
viewCharacterization(
  resultFolder = file.path(tempdir(),'view')
)
}


Run the code above in your browser using DataLab